"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import mms_python_client
from mms_python_client.api.groups_api import GroupsApi  # noqa: E501


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_local_group(self):
        """Test case for create_local_group

        """
        pass

    def test_delete_local_group(self):
        """Test case for delete_local_group

        """
        pass

    def test_get_all_groups(self):
        """Test case for get_all_groups

        """
        pass

    def test_get_group(self):
        """Test case for get_group

        """
        pass

    def test_update_group_users(self):
        """Test case for update_group_users

        """
        pass


if __name__ == '__main__':
    unittest.main()
