"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import mms_python_client
from mms_python_client.api.projects_api import ProjectsApi  # noqa: E501


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_or_update_projects(self):
        """Test case for create_or_update_projects

        """
        pass

    def test_delete_project(self):
        """Test case for delete_project

        """
        pass

    def test_get_all_projects(self):
        """Test case for get_all_projects

        """
        pass

    def test_get_project(self):
        """Test case for get_project

        """
        pass

    def test_get_project_schema_options(self):
        """Test case for get_project_schema_options

        """
        pass


if __name__ == '__main__':
    unittest.main()
