"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import mms_python_client
from mms_python_client.api.elements_api import ElementsApi  # noqa: E501


class TestElementsApi(unittest.TestCase):
    """ElementsApi unit test stubs"""

    def setUp(self):
        self.api = ElementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_or_update_elements(self):
        """Test case for create_or_update_elements

        """
        pass

    def test_delete_element(self):
        """Test case for delete_element

        """
        pass

    def test_delete_elements(self):
        """Test case for delete_elements

        """
        pass

    def test_get_all_elements(self):
        """Test case for get_all_elements

        """
        pass

    def test_get_element(self):
        """Test case for get_element

        """
        pass

    def test_get_elements(self):
        """Test case for get_elements

        """
        pass


if __name__ == '__main__':
    unittest.main()
