"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import mms_python_client
from mms_python_client.api.search_api import SearchApi  # noqa: E501


class TestSearchApi(unittest.TestCase):
    """SearchApi unit test stubs"""

    def setUp(self):
        self.api = SearchApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_basic_search(self):
        """Test case for get_basic_search

        """
        pass

    def test_post_basic_search(self):
        """Test case for post_basic_search

        """
        pass


if __name__ == '__main__':
    unittest.main()
