"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import mms_python_client
from mms_python_client.api.commits_api import CommitsApi  # noqa: E501


class TestCommitsApi(unittest.TestCase):
    """CommitsApi unit test stubs"""

    def setUp(self):
        self.api = CommitsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_commit(self):
        """Test case for get_commit

        """
        pass

    def test_get_commits(self):
        """Test case for get_commits

        """
        pass

    def test_get_element_commits(self):
        """Test case for get_element_commits

        """
        pass

    def test_get_ref_commits(self):
        """Test case for get_ref_commits

        """
        pass


if __name__ == '__main__':
    unittest.main()
