"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import mms_python_client
from mms_python_client.api.auth_api import AuthApi  # noqa: E501


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self):
        self.api = AuthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check_authentication_token(self):
        """Test case for check_authentication_token

        """
        pass

    def test_create_authentication_token(self):
        """Test case for create_authentication_token

        """
        pass

    def test_create_user(self):
        """Test case for create_user

        """
        pass

    def test_get_authentication_token(self):
        """Test case for get_authentication_token

        """
        pass

    def test_get_branch_permissions(self):
        """Test case for get_branch_permissions

        """
        pass

    def test_get_org_permissions(self):
        """Test case for get_org_permissions

        """
        pass

    def test_get_project_permissions(self):
        """Test case for get_project_permissions

        """
        pass

    def test_get_users(self):
        """Test case for get_users

        """
        pass

    def test_lookup_permissions(self):
        """Test case for lookup_permissions

        """
        pass

    def test_update_branch_permissions(self):
        """Test case for update_branch_permissions

        """
        pass

    def test_update_org_permissions(self):
        """Test case for update_org_permissions

        """
        pass

    def test_update_password(self):
        """Test case for update_password

        """
        pass

    def test_update_project_permissions(self):
        """Test case for update_project_permissions

        """
        pass


if __name__ == '__main__':
    unittest.main()
