"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import mms_python_client
from mms_python_client.model.element import Element
from mms_python_client.model.rejection import Rejection
globals()['Element'] = Element
globals()['Rejection'] = Rejection
from mms_python_client.model.elements_search_response import ElementsSearchResponse


class TestElementsSearchResponse(unittest.TestCase):
    """ElementsSearchResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testElementsSearchResponse(self):
        """Test ElementsSearchResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ElementsSearchResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
