"""
    MMS Reference Implementation API

    Documentation for MMS API  # noqa: E501

    The version of the OpenAPI document: 4.0.3
    Contact: mms@openmbee.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import mms_python_client
from mms_python_client.api.notebooks_api import NotebooksApi  # noqa: E501


class TestNotebooksApi(unittest.TestCase):
    """NotebooksApi unit test stubs"""

    def setUp(self):
        self.api = NotebooksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_or_update_notebooks(self):
        """Test case for create_or_update_notebooks

        """
        pass

    def test_get_all_notebooks(self):
        """Test case for get_all_notebooks

        """
        pass

    def test_get_notebook(self):
        """Test case for get_notebook

        """
        pass

    def test_get_notebooks(self):
        """Test case for get_notebooks

        """
        pass


if __name__ == '__main__':
    unittest.main()
